@@ -122,12 +122,17 @@ RdpHostPreferences::~RdpHostPreferences()
 {
 }
 
-QWidget *RdpHostPreferences::createProtocolSpecificConfigPage()
+QWidget *RdpHostPreferences::createProtocolSpecificConfigPage(QWidget *sshTunnelWidget)
 {
     QWidget *rdpPage = new QWidget();
     rdpUi.setupUi(rdpPage);
+    if (sshTunnelWidget) {
+        rdpUi.settingsTabs->addTab(sshTunnelWidget, sshTunnelWidget->windowTitle());
+    }
 
     rdpUi.kcfg_ScaleToSize->setChecked(scaleToSize());
+    rdpUi.kcfg_ConsoleMode->setChecked(consoleMode());
+    rdpUi.kcfg_PreventSessionLock->setChecked(preventSessionLock());
     rdpUi.kcfg_Height->setValue(height());
     rdpUi.kcfg_Width->setValue(width());
     rdpUi.kcfg_Resolution->setCurrentIndex(int(resolution()));
@@ -233,6 +238,8 @@ void RdpHostPreferences::acceptConfig()
     HostPreferences::acceptConfig();
 
     setScaleToSize(rdpUi.kcfg_ScaleToSize->isChecked());
+    setConsoleMode(rdpUi.kcfg_ConsoleMode->isChecked());
+    setPreventSessionLock(rdpUi.kcfg_PreventSessionLock->isChecked());
     setWidth(rdpUi.kcfg_Width->value());
     setHeight(rdpUi.kcfg_Height->value());
     setResolution(Resolution(rdpUi.kcfg_Resolution->currentIndex()));
@@ -272,6 +279,26 @@ void RdpHostPreferences::setScaleToSize(bool scale)
     m_configGroup.writeEntry("scaleToSize", scale);
 }
 
+bool RdpHostPreferences::consoleMode() const
+{
+    return m_configGroup.readEntry("consoleMode", Settings::consoleMode());
+}
+
+void RdpHostPreferences::setConsoleMode(bool enabled)
+{
+    m_configGroup.writeEntry("consoleMode", enabled);
+}
+
+bool RdpHostPreferences::preventSessionLock() const
+{
+    return m_configGroup.readEntry("PreventSessionLock", Settings::preventSessionLock());
+}
+
+void RdpHostPreferences::setPreventSessionLock(bool enabled)
+{
+    m_configGroup.writeEntry("PreventSessionLock", enabled);
+}
+
 RdpHostPreferences::Resolution RdpHostPreferences::resolution() const
 {
     return Resolution(m_configGroup.readEntry("resolution", Settings::resolution()));
